pub struct CreateInbox {
pub initial_identifier: String,
pub nonce: u64,
pub initial_identifier_signature: Option<Signature>,
pub initial_identifier_kind: i32,
pub relying_party: Option<String>,
}Expand description
The first entry of any XID log. The XID must be deterministically derivable from the address and nonce. The recovery address defaults to the initial associated_address unless there is a subsequent ChangeRecoveryAddress in the log.
Fields
initial_identifier: Stringnonce: u64initial_identifier_signature: Option<Signature>Must be an addressable member
initial_identifier_kind: i32relying_party: Option<String>Should be provided if identifier kind is passkey
Implementations
Sourceimpl CreateInbox
impl CreateInbox
Sourcepub fn initial_identifier_kind(&self) -> IdentifierKind
pub fn initial_identifier_kind(&self) -> IdentifierKind
Returns the enum value of initial_identifier_kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_initial_identifier_kind(&mut self, value: IdentifierKind)
pub fn set_initial_identifier_kind(&mut self, value: IdentifierKind)
Sets initial_identifier_kind to the provided enum value.
Sourcepub fn relying_party(&self) -> &str
pub fn relying_party(&self) -> &str
Returns the value of relying_party, or the default value if relying_party is unset.