pub struct IdentityUpdate {
pub actions: Vec<IdentityAction>,
pub client_timestamp_ns: u64,
pub inbox_id: String,
}Expand description
One or more identity actions that were signed together. Example: [CreateXid, AddAssociation, ChangeRecoveryAddress]
- The batched signature text is created by concatenating the signature text of each association together with a separator, ‘\n\n\n’.
- The user signs this concatenated result.
- The resulting signature is added to each association proto where relevant. The same signature may be used for multiple associations in the array.
Fields
actions: Vec<IdentityAction>client_timestamp_ns: u64inbox_id: StringTrait Implementations
Sourceimpl Clone for IdentityUpdate
impl Clone for IdentityUpdate
Sourcefn clone(&self) -> IdentityUpdate
fn clone(&self) -> IdentityUpdate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdentityUpdate
impl Debug for IdentityUpdate
Sourceimpl Default for IdentityUpdate
impl Default for IdentityUpdate
impl<'de> Deserialize<'de> for IdentityUpdate
impl<'de> Deserialize<'de> for IdentityUpdate
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for IdentityUpdate
impl Message for IdentityUpdate
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Name for IdentityUpdate
impl Name for IdentityUpdate
Sourceconst NAME: &'static str = "IdentityUpdate"
const NAME: &'static str = "IdentityUpdate"
Simple name for this
Message.
This name is the same as it appears in the source .proto file, e.g. FooBar.Sourceconst PACKAGE: &'static str = "xmtp.identity.associations"
const PACKAGE: &'static str = "xmtp.identity.associations"
Package name this message type is contained in. They are domain-like
and delimited by
., e.g. google.protobuf.Sourcefn full_name() -> String
fn full_name() -> String
Fully-qualified unique name for this
Message.
It’s prefixed with the package name and names of any parent messages,
e.g. google.rpc.BadRequest.FieldViolation.
By default, this is the package name followed by the message name.
Fully-qualified names must be unique within a domain of Type URLs.Sourceimpl PartialEq for IdentityUpdate
impl PartialEq for IdentityUpdate
Sourcefn eq(&self, other: &IdentityUpdate) -> bool
fn eq(&self, other: &IdentityUpdate) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for IdentityUpdate
impl Serialize for IdentityUpdate
impl StructuralPartialEq for IdentityUpdate